@@ -1,7 +1,11 @@
 from .expr import Expr
 
+
 class LeafExpr(Expr):
     """Leaf expression base class."""
-    pass
+
+    def has_return(self):
+        return False
+
 
 LeafExpr.__module__ = "pyteal"
